@@ -4,10 +4,10 @@ from __future__ import annotations
 from argparse import ArgumentParser
 from pathlib import Path
 
-from chemex import __version__
-from chemex import chemex
-from chemex import tools
+from chemex import __version__, chemex
 from chemex.parameters.spin_system import SpinSystem
+from chemex.tools.pick_cest import pick_cest
+from chemex.tools.plot_param import plot_param
 
 
 def build_parser():
@@ -21,10 +21,12 @@ def build_parser():
 
     parser = ArgumentParser(description=description, prog="chemex")
 
-    parser.set_defaults(func=lambda x: parser.print_usage())
+    parser.set_defaults(func=lambda _: parser.print_usage())
 
     parser.add_argument(
-        "--version", action="version", version=f"{parser.prog} {__version__}"
+        "--version",
+        action="version",
+        version=f"{parser.prog} {__version__}",
     )
 
     subparsers = parser.add_subparsers(dest="commands")
@@ -94,7 +96,7 @@ def build_parser():
         metavar="ID",
         nargs="+",
         help="Residue(s) to include in the fit",
-        type=SpinSystem,
+        type=SpinSystem.from_name,
     )
 
     fit_parser.add_argument(
@@ -103,7 +105,7 @@ def build_parser():
         metavar="ID",
         nargs="+",
         help="Residue(s) to exclude from the fit",
-        type=SpinSystem,
+        type=SpinSystem.from_name,
     )
 
     # parser for the positional argument "simulate"
@@ -176,10 +178,11 @@ def build_parser():
 
     # parser for the positional argument "pick_cest"
     pick_cest_parser = subparsers.add_parser(
-        "pick_cest", help="Plot CEST profiles for dip picking"
+        "pick_cest",
+        help="Plot CEST profiles for dip picking",
     )
 
-    pick_cest_parser.set_defaults(func=tools.pick_cest.pick_cest)
+    pick_cest_parser.set_defaults(func=pick_cest)
 
     pick_cest_parser.add_argument(
         "-e",
@@ -202,10 +205,11 @@ def build_parser():
 
     # parser for the positional argument "pick_cest"
     plot_param_parser = subparsers.add_parser(
-        "plot_param", help="Plot one selected parameter from a 'parameters.fit' file"
+        "plot_param",
+        help="Plot one selected parameter from a 'parameters.fit' file",
     )
 
-    plot_param_parser.set_defaults(func=tools.plot_param.plot_param)
+    plot_param_parser.set_defaults(func=plot_param)
 
     plot_param_parser.add_argument(
         "-p",
